@@ -1,3 +1,11 @@
+#include "config.h"
+#ifdef I_STDLIB
+#define HAVE_STDLIB_H
+#endif
+#ifdef I_STRING
+#define HAVE_STRING_H
+#endif
+
 /*
  * syck.h
  *
